/*
 * $Header: /home/cvspublic/jakarta-commons-sandbox/resources/src/test/org/apache/commons/resources/impl/TestResources.java,v 1.5 2003/08/17 03:34:14 craigmcc Exp $
 * $Revision: 1.5 $
 * $Date: 2003/08/17 03:34:14 $
 *
 * ====================================================================
 *
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Commons", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */


package org.apache.commons.resources.impl;


import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;

import org.apache.commons.resources.ResourcesException;
import org.apache.commons.resources.ResourcesKeyException;


/**
 * <p>Concrete implementation of {@link Resources} for unit tests.</p>
 *
 * @author Craig R. McClanahan
 * @version $Revision: 1.5 $ $Date: 2003/08/17 03:34:14 $
 */

public class TestResources extends ResourcesBase {


    // ----------------------------------------------------------- Constructors


    // Construct a test instance with the specified name
    public TestResources(String name) {
        super(name);
    }


    // ----------------------------------------------------- Instance Variables


    // Has this instance been initialized?
    protected boolean initialized = false;


    // Map of resource String values
    protected Map map = new HashMap();


    // ------------------------------------------------------ Lifecycle Methods


    // Initialize this Resources instance
    public void init() throws ResourcesException {

        super.init();
        map.put("test.specific", "[test] SPECIFIC");
        map.put("test.inherit", "[test] INHERIT");
        initialized = true;

    }


    // Destroy this Resources instance
    public void destroy() throws ResourcesException {

        super.destroy();
        map.clear();
        initialized = false;

    }


    // ------------------------------------------------------------- Properties


    // Return the keys for all defined Resources
    public Iterator getKeys() {

        List results = new ArrayList();
        results.add("test.base");
        results.add("test.specific");
        results.add("test.inherit");
        results.add("test.message");
        return (results.iterator());

    }


    // Has this instance been initialized?
    public boolean isInitialized() {
        return (this.initialized);
    }


    // ---------------------------------------------- Content Retrieval Methods


    /**
     * <p>Return the content for the specified <code>key</code> as an
     * Object, localized based on the specified <code>locale</code>
     * and/or <code>timeZone</code>.</p>
     *
     * @param key Identifier for the requested content
     * @param locale Locale with which to localize retrieval,
     *  or <code>null</code> for the default Locale
     * @param timeZone TimeZone with which to localize retrieval,
     *  or <code>null</code> for the default TimeZone
     *
     * @exception ResourcesException if an error occurs retrieving or
     *  returning the requested content
     */
    public Object getObject(String key, Locale locale, TimeZone timeZone)
        throws ResourcesException {

        Object value = map.get(key);
        if (value == null) {
            if (isReturnNull()) {
                return (null);
            } else {
                throw new ResourcesKeyException(key);
            }
        }
        return (value);

    }


}
